<div align="center">

# `fossiler v0.0.4.6` : a suite tool of fossils finding
**Hengchi Chen**

[**Bioinformatics & Evolutionary Genomics Group**](https://www.vandepeerlab.org/people/heche)**, VIB-UGent Center for Plant Systems Biology**

[**Upper Limits**](#upper-limits) |
[**Fossil Justifications**](#fossil-justifications) |
[**References**](#references) |
[**Monilophyta**](#monilophyta)
</div>

## Fossil Justifications
Below we give a detailed justification for each accepted fossil regarding the phylogenetic assignment and age bounds.

:leaves: and :microscope: denote macrofossils and microfossils, respectively.

:leaves: **${\text{\color{green} Fossil \ No.0}}$**

**Brief Desription:** The oldest fossil found in Nymphaeales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Nymphaeites choffatii*, young leaves (specimen 184-Pb. DBAV-UERJ), mature leaves (180a,b-Pb. DBAV-UERJ with an incomplete petiole; 181a,b-183-Pb. DBAV-UERJ), aggregates of roots still showing calyptra (185-190-Pb, DBAV-UERJ), Parnaíba Basin, Codó Formation, Cretaceous of Brazil.

**Phylogenetic Justification:** This genus *Nymphaeites* was defined to be distinguished with non-peltate leaves with palmate veins branching at acute angles by Heer at 1870. (Bell, 1949) extended the diagnosis of *Nymphaeites* to non-peltate leaves with mixed pinnate and palmate veins as well as peltate and subpeltate leaves with similar venation and a typical petiole, since the secondary vein branches in palmate leaves may suggest a pinnate arrangement. (L. Duarte and R.Silva Santos, 1993) described the leaf remnants found at Parnaíba Basin with common features of symmetrical, orbicular peltate to wide obvate (1.2:1), base symmetrical, rounded to normal obtuse, teeth found along the upper two-thirds of the margin but not along the lateral basal portions, petiole strong and thick, preserved portions about 1.1cm long and 0.6cm width, petiolar insertion at the base of the blade, and specimen-specific features of margin dentate, teeth with a sharp apex, the basal and apical portions straight (182-Pb. DBAV-UERJ) and concave (181-184-Pb. DBAV-UERJ). While the root remnants therein were found to have two distinguished types of arrangement, main roots bearing thin and unbranched secondary roots with preserved calyptras, as well as overlapping aggregates also with preserved calyptras. The representation of leaf and root remnants suggested its assignment to *Nymphaeites choffatii*, according to (L. Duarte and R.Silva Santos, 1993).

**Age Justification:** The sedimentary rock from Parnaíba Basin, Codó Formation was thought to be of Aptian/Albian age (Lima, 1982). Based on numerous findings of the *Nymphaeites* fossil in shales of Aptian age, Duarte and R.Silva Santos suggested the age of the *Nymphaeites* fossil to be within Aptian. Thus, we use 121.4-113.0 mya as the age bound for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.1}}$**

**Brief Desription:** The oldest fossil found in Austrobaileyales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Cretacaeiporites cf. mulleri*, pollen grains on sample CAS-7, Araripe Basin, Rio da Batateira Formation, Cretaceous of Brazil.

**Phylogenetic Justification:** (Ulrich Heimhofer and Peter-A. Hochuli, 2010) proposed the fossil assignment as *Cretacaeiporites cf. mulleri* based on the observed morphology using Olympus BX 51 microscope.

**Age Justification:** The stratigraphic position of the Rio da Batateira Formation is confined by the occurrences of a number of age-diagnostic gymnosperm pollen taxa including *Afropollis aff. jardinus*, *A. jardinus* and *Sergipea cf. variverrucata* as well as the spore *Crybelosporites pannuceus*. According to (Doyle et al., 1982 and Doyle et al., 1992), the dominance of the heteropolar inaperturate taxon *Afropollis aff. jardinus* and the absence of zonosulcate forms (*A. zonatus* and *A. aff. zonatus*) indicate a late early Aptian (*A. aff. jardinus*) or younger age (*A. jardinus*). In the Rio da Batateira Formation, the maximum abundances of heteropolar *Afropollis* forms reach up to 17% of the whole palynoflora. According to the Northern Gabon reference record of (Doyle et al., 1982), this peak may be part of the second *Afropollis* maximum in palynozone C-X,which covers the uppermost Aptian–Lower Albian interval. (Pons et al., 1996) proposed a late Aptian age for the “Fundão” unit located below the Rio da Batateira Formation. While (Coimbra et al., 2002) also proposed an late Aptian *S. variverrucata* palynozone for the Rio da Batateira Formation. Based on the essentially continuous occurrence of *S. variverrucata* in core material covering the Crato, Ipubi and Santana Formations, (Regali, 2001) and (Rios-Netto and Regali, 2007) argued in favour of an Aptian age for the entire succession. Desipte the age uncertainty concerning the Santana Formation, a late Aptian age was agreed on the Rio da Batateira Formation. Thus, we used 121.4-113.0 mya as the age bound for this fossil, according to (Ogg et al., 2016) and the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.2}}$**

**Brief Desription:** The oldest fossil found in Piperales.

**Age Bounds:** 72.3 - 66.0 mya.

**Taxon & Specimen & Rock:** *Rosannia manika* Srivastava emend, spore-pollen labeled as MPEF–Palin 106 b: W45 on sample M3 of San Ramón section of the Lefipán Formation, Northwestern Patagonia, Cretaceous of Argentina.

**Phylogenetic Justification:** (Viviana et al., 2012) proposed the fossil assignment as *Rosannia manika* Srivastava emend following the revised generic diagnosis of (Srivastava and Braman 2010) featured with an obligate ana-ulcerate tetrad with calymmate exine and granulose supratectal ornamentation and a close morphological affinity with the pollen of extant *Lactoris fernandeziana* Phil, which was thus suggested to be assigned to Lactoridaceae.

**Age Justification:** Cluster analysis (Q mode) of (Viviana et al., 2012) revealed two stratigraphically well ordered major groups of samples: group A comprised of the Maastrichtian samples M1-M3, group B comprised of all early Danian samples. The highest proportional abundances of *Rosannia manika* Srivastava emend emerged at sample M3 as 0.389. Thus, we used 72.3 - 66.0 mya as the age bound for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.3}}$**

**Brief Desription:** The oldest fossil found in Canellales.

**Age Bounds:** 72.3 - 66.0 mya (changed into 121.4 - 113.0 mya according to (Santiago el al, 2020)).

**Taxon & Specimen & Rock: *Pseudowinterapollis couperi* Krutzsch, 1970 emend, pollen grains labeled as MPM-MP 1952 101,3/8 on the Monte Chico Formation, Upper Cretaceous, Santa Cruz, Cretaceous of Argentina.

**Phylogenetic Justification:** (Leticia Karina Povilauskas, 2013) proposed the fossil assignment as *Pseudowinterapollis couperi* Krutzsch, 1970 emend, following the diagnosis of (Mildenhall, 1979).

**Age Justification:** Based on the stratigraphic distribution of the identified fossil species, mainly in Argentina and Antarctica, together with the preliminary analysis of spores, (Leticia Karina Povilauskas, 2013) suggested a Maastrichtian age of the studied sedimentary rock. Thus, we used 72.3 - 66.0 mya as the age bound for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.4}}$**

**Brief Desription:** The oldest fossil found in Magnoliales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Endressinia brasiliana* Mohr and Bernardes-de-Oliveira, leaves and flowers specimen labled as MB.PB.2001/1455, Araripe Basin, Crato Formation, Cretaceous of Brazil.

**Phylogenetic Justification:** Based on the characters featuring the genus *Endressinia*, small (less than or ca.10mm in diameter), multiparted flowers, consisting of tepals and spirally arranged inner organs, borne on a more or less flattened receptacle, towards the center, several spirally arranged rows of flat, elongated staminodes with marginal glands and in the center, ca.20 narrowly apocarpous follicles with small, distinct, glabrous stigmatic area, (Mohr and Bernardes‐de‐Oliveira, 2004) assigned the observed fossil displaying a branching axis with attached simple, narrowly ovate leaves and several terminal small flowers as *Endressinia brasiliana*, and suggested the genus *Endressinia* of being sister to Eupomatiaceae since only Himantandraceae and Eupomatiaceae among recent Magnoliales share the character of having staminodes with glands, which are broad in Eupomatia. The proability of representing an extinct lineage with convergent staminode morphology was also proposed therein.

**Age Justification:** As discussed in fossil No.1, a late Aptian age was also agreed on the Crato Formation. Thus, we used 121.4 - 113.0 mya as the age bound for this fossil, according to (Ogg et al., 2016) and the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.5}}$**

**Brief Desription:** The oldest fossil found in Laurales.

**Age Bounds:** 113.0 - 105.68 mya.

**Taxon & Specimen & Rock:** *Appomattoxia ancistrophora* gen. et sp. nov., fruit and pollen grains with holotype specimen PP44001 and more than 450 other specimens from Puddledock samples 82, 83, 142, 143, 151, 152, 156, palynological Subzone IIB, Tarmac Lone Star Industries Puddledock locality in the Potomac Group sequence of Virginia, Cretaceous of the United States.

**Phylogenetic Justification:** The genus *Appomattoxia* and fossil *Appomattoxia ancistrophora* was first established by (Friis et al., 1995) based on well-preserved fruiting units and associated pollen. Fruiting units are small, unilocular, and with a single, pendulous, orthotropous seed. The fruit surface is characterized by densely spaced unicellular spines with hooklike tips, which probably functioned in biotic dispersal. Pollen grains adhering to the stigmatic area of many specimens are monocolpate and tectate with granular to columellate infratectal structure. The fossil *Appomattoxia ancistrophora* shared an exclusive combination of characters with magnoliid taxa including Piperales, Laurales and Circaeasteraceae. Since *Appomattoxia ancistrophora* differs from extant Piperales in having a pendulous instead of erect ovule, and differs from extant *Circaeaster* in details of the fruit wall and the presence of monosulcate instead of tricolpate pollen, (Friis et al., 1995) suggested the genus *Appomattoxia* to be closest to Laurales.

**Age Justification:** The age of Potomac Group palynological Subzone IIB has not been established with certainty, although it is generally believed to fall within the Albian. (Doyle and Robbins, 1977) dated basal Subzone IIB of the Potomac Group to about the Early/Middle Albian boundary and middle Subzone IIB to late Middle Albian. Subsequent palynological correlations of the Potomac Group sequence with material from other areas for which there is better marine control indicate that Subzone IIB may extend down into the Early Albian ((Doyle, 1992). Palynological Subzone IIC, which overlies Subzone IIB, has been interpreted as latest Albian (Doyle and Robbins, 1977). The palynological Subzone IIB may therefore be as old as the Early Albian, and are probably not younger than the Middle Albian. Thus, we used 113.0 - 105.68 mya as the age bound for this fossil, according to (Scott, 2009) and the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.6}}$**

**Brief Desription:** The oldest fossil found in Chloranthales.

**Age Bounds:** 139.8 - 125.77 mya

**Taxon & Specimen & Rock:** *Clavatipollenites sp.* and *Clavatipollenites minutus*, spores and pollen grains, in well/slide K2C2B3, H19/0, K2C2B2, R23/0 and Z1C7B3, S21/3, *Bullasporis bifidum*/*Klukisporites scaberis* Palynozone, Helez Formation, Cores 1, 2, 3 and 5, Kurnub Group, Kokhav 2, Cretaceous coastal plain of Israel. 

**Phylogenetic Justification:** Two *Clavatipollenites sp.* and one *Clavatipollenites minutus* fossils were described in (Brenner and Bickoff, 1992). The assignment of *Clavatipollenites* followed the definition of (Brenner, 1963). While the *Clavatipollenites sp. A* is distinguished by the faintly striate apperance and similiar to the *Clavatipollenites sp. 1* found in Zone C-V1 from Africa.

**Age Justification:** *Clavatipollenites minutus* was found in Helez and Zeweira Formations. While *Clavatipollenites sp.* fossils were restricted to the Helez Formation. The Zeweira Formation was divided into two subzones based on the first occurrence of pollen types in core 6. Core 6 and 7 have very similar spore and pollen assemblages, but core 6 contains the first appearance of the lower marker form *Brenneripollis reticulatus* as well as the first occurrence of the tricolpate pollen and *Afropollis jardinus*. A late Barremian age is therefore suggested for the lower part of the Zeweira Formation (core 7), while the new forms mentioned above in core 6 suggest a early Aptian age. (Grader and Reiss, 1958) laid the foundation for the currently accepted stratigraphy of the Helez Formation by studying subsurface samples from the Helez 1, 2, 3 and Negba 1 wells, and used micro-and megafaunal evidence to date the basal Cretaceous. The dating results from microfauna suggested the age as late Valanginian to early Hauterivian. Specifically, the upper part of units L.CrIIa (Hm, H1, H2, H3) is interpreted to be early Hauterivian based on the presence of the ammonites *Leupoldia* and *Saynella*, while the lower part was determined to be of Valanginian age because it's immediately below early Hauterivian sediments and above Berriasian to Valanginian sediments of the L.CrI unit. Taking into account that *Clavatipollenites sp. B* emerged at H1 and H2, we suggested setting late Valanginian to early Hauterivian as the age of the fossil. The age bound was set as 139.8 - 125.77 mya for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.7}}$**

**Brief Desription:** The oldest fossil found in Commelinales.

**Age Bounds:** 56.0 - 33.9 mya.

**Taxon & Specimen & Rock:** *Eichhornia sp.*, megafossils in root and stem fragments, the Deccan Intertrappean beds, Eocene of India.

**Phylogenetic Justification:** (Patil and Singh, 1978) described and assigned the fossil as *Eichhornia sp.* affiliated to Pontederiaceae.

**Age Justification:** The sedimentary rock was dated as Eocene. Thus, we used 56.0 - 33.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.8}}$**

**Brief Desription:** The oldest fossil found in Zingiberales.

**Age Bounds:** 83.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Spirematospermum chandlerae*, macrofossils, Neuse River Cut-Off, Wayne County, Black Creek Formation, North Carolina, Cretaceous of the United States.

**Phylogenetic Justification:** (Friis et al., 1988) described the fossil as *Spirematospermum chandlerae*. (Andrews, 1970) assigned the genus *Spirematospermum* to be within Zingiberaceae based on the morphology of a fruit fossil deposited in Hordle, Hampshire, England.

**Age Justification:** The Black Creek Formation was dated as Campanian. Thus, we used 83.8 - 71.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.9}}$**

**Brief Desription:** The oldest fossil found in Poales.

**Age Bounds:** 124.85 - 124.35 mya. 

**Taxon & Specimen & Rock:** *Eragrosites changii*, spikelets and panicle, Holotype: pl. ll-2 (PB17803), Yixian Formation (Jehol Group), Cretaceous of China.

**Phylogenetic Justification:** (Cao et al., 1998) described the morphology of the fossil as larger panicle, about 14 cm in incompletely preserved length and at least 10 cm in width; rachis about 3 mm wide at the base, narrowing gradually to the upper portion of inflorescence, oppositely branching 3 times, apart from each other, with longitudinal striations and glandula-like appendages on the surface of rachis and branches; bracts absent. Spikelets arranged in panicle, ovate to elongatedly elliptical in outline, about 5 mm long, composed of the biserial "florets", likely bearing two glumes at its base. The spikelets and inflorescences of the present specimens extremely resemble those of the existing plant *Eragrostis Wolf* of Poaceae. The difference between them is that the inflorescence branches of the latter are generally alternate and sometimes partly opposite even verticillate, while those of the former are consistently opposite. The new genus was accordingly named as *Eragrosties* for its similarity to *Eragrostis*.

**Age Justification:** The Jianshangou bed was dated by (Swisher et al., 1999) using <sup>40</sup>Ar/<sup>39</sup>Ar method as 124.60 ± 0.25 mya for Sample P1T-2 and 124.61 ± 0.20 mya for Sample P4T-1. Here, we used the union set of the two estimates and set the age of the fossil as 124.85 - 124.35 mya.

:microscope: **${\text{\color{green} Fossil \ No.10}}$**

**Brief Desription:** The oldest fossil found in Arecales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Spinizonocolpites sp.*, palynomorphs, Bajo Comisión, Rio Mayer Formation, Cretaceous of Argentina.

**Phylogenetic Justification:** (Archangelsky et al., 2012) classified the fossil as to *Spinizonocolpites*. (Huang et al., 2023) based on the observation of the scanned electron microscopy micrographs of sporomorphs assigned the *Spinizonocolpites* to Arecaceae.

**Age Justification:** The age of Rio Mayer Formation was dated as Upper Aptian (Archangelsky et al., 2012). Thus, we used the age 121.4 - 113.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/). 

:leaves: **${\text{\color{green} Fossil \ No.11}}$**

**Brief Desription:** The oldest fossil found in Asparagales.

**Age Bounds:** 27.82 - 15.97 mya (changed into 27.82 - 23.03 mya, according to (Santiago et al., 2020)).

**Taxon & Specimen & Rock:** *Phormium sp.*, leaf litter, cuticle and pollen grain, Newvale Mine leaf beds, fossil site F45/f0394, Newvale assemblage, Gore Lignite Measures, the Late Oligocene to Early Miocene southern New Zealand.

**Phylogenetic Justification:** All of the macrofossils reported by (Ferguson et al., 2010) have exceptionally well-preserved cuticle. (Ferguson et al., 2010) decided the phylogenetic assignment of the fossil *Phormium sp.* by the observation of its partial leaf, cuticle, and pollen grain from Newvale Mine leaf beds. (Ferguson et al., 2010) regarded it as members of Asparagaceae.

**Age Justification:** The age of the middle Gore Lignite Measures is Late Oligocene or Early Miocene (Waitakian to Altonian Stage) based on studies of palynofloras of Oligocene and Miocene strata of Otago and Southland by (Pocknall and Mildenhall, 1984) and (Mildenhall and Pocknall, 1989). Given the close association between marine strata of Waitakian age and the lower and middle Gore Lignite Measures in the Waimumu area (Isaac and Lindqvist, 1990), (Ferguson et al., 2010) suggested the age of the lignite as Waitakian (late Oligocene to early Miocene). Thus, we used the age 27.82 - 15.97 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.12}}$**

**Brief Desription:** The oldest fossil found in Liliales.

**Age Bounds:** 125.77 - 121.4 mya.

**Taxon & Specimen & Rock:** *Liliacidites sp.*, pollen grains with sample labeled as Sh-1, 576-582, El Wadi El Gadid, Dakhla Oasis Area, Six Hills Formation, Cretaceous of Egypt.

**Phylogenetic Justification:** The recognized differences under a light microscope, for instance, the wider sulci gaping in the middle of the grain of *Liliacidites* indicated the phylogenetic assignment of the fossil as to *Liliacidites sp.* (Schrank and Mahmoud., 2002). Archangelsky suggested the assignment of genus *Liliacidites* to be within Liliales (Archangelsky, 1973).

**Age Justification:** The age of Six Hills Formation was estimated to be as late Barremian (Schrank and Mahmoud., 2002). Thus, we used the age 125.77 - 121.4 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.13}}$**

**Brief Desription:** The oldest fossil found in Pandanales.

**Age Bounds:** 93.9 - 89.5 mya

**Taxon & Specimen & Rock:** *Nuhliantha nyanzaiana*, Holotype L. H. Bailey Hortorium Paleobotanical Collection CUPC 1267, the Old Crossman Clay Pit locality in Sayreville, South Amboy Fire Clay, Raritan Formation, New Jersey, Cretaceous of the United States.

**Phylogenetic Justification:** Two different cladistic analyses were performed by (Gandolfo et al., 2002): the first they composed a character matrix consisting of stomata, floral expression, perianth petaloid, perianth connation, perianth curvature, zygomorphy, perigonal nectaries, staminodia, connate stamen filament, connective protrusion, anther attachment, anther dehiscence, sporangia per anther bisporangial, endothecial wallthickenings, pollen units monads, pollen apertures sulcate, number of pollen apertures one, pollen aperture margin nonannulate, pollen sculpturing reticulate and psilate, which was then subject to parsimony analyses to decide the overall phylogenetic placement of the fossil taxa and their relationships with extant monocot taxa; the second they formulated another matrix comprised of outgroup Petrosaviaceae and all the extant
Triuridaceae genera (including *Lacandonia*) of 20 morphological characters to explore the relationships of the fossil taxa in more detail with the extant members of the Triuridaceae. Based on the cladistic analyses, (Gandolfo et al., 2002) confirm the affinities of the fossil *Nuhliantha nyanzaiana* with modern Triuridaceae.

**Age Justification:** On the basis of stratigraphic and palynological data, the South Amboy Fire Clay, Raritan Formation was dated as the age of Turonian (Doyle and Robbins, 1977; Harland et al., 1989). Thus, we used the age 93.9 - 89.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.14}}$**

**Brief Desription:** The oldest fossil found in Dioscoreales.

**Age Bounds:** 37.71 - 33.9 mya.

**Taxon & Specimen & Rock:** *Dioscorea sp.*, Florissant Flora, Colorado, Eocene of the United States.

**Phylogenetic Justification:** (MacGinitie, 1953) reported the fossil *Dioscorea sp.* at the Florissant Beds of Colorado. (Knowlton, 1919) suggested the *Dioscorea sp.* to be assigned into Dioscoreaceae.

**Age Justification:** The age of the Florissant Beds of Colorado was dated as Priabonian. Thus, we used the age 37.71 - 33.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.15}}$**

**Brief Desription:** The oldest fossil found in Ceratophyllales.

**Age Bounds:** 113.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Ceratophyllum sp.*, Cheyenne Sandstone Formation, Belvidere, Cretaceous of the United States.

**Phylogenetic Justification:** (Huang and Dilcher, 1994) reported the fossil *Ceratophyllum sp.* at the Cheyenne Sandstone Formation of Kiowa County, Kansas. The assignment of the fossil to Ceratophyllaceae follows the definition of Carl Linnaeus. 

**Age Justification:** The age of the Cheyenne Sandstone Formation is dated as Albian (Huang and Dilcher, 1994). Thus, we used the age 113.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.16}}$**

**Brief Desription:** The oldest fossil found in Ranunculales.

**Age Bounds:** 121.4 - 100.5 mya.

**Taxon & Specimen & Rock:** *Teixeiraea lusitanica*, flower and pollen grains, Vale de Agua 320, Famalicao Member (Figueira da Foz Formation), Cretaceous of Portugal.

**Phylogenetic Justification:** (Balthazar et al, 2005) first described the genus and species with features including: the flower is actinomorphic and unisexually male; at the base of the bud there are several bracts of different sizes, which are followed by sepal-like and petal-like tepals; bracts and perianth organs seem to be arranged spirally and to exhibit transitions between different organ categories; the androecium has numerous stamens in two sizes, but with unclear arrangement; pollen is small and tricolpate with a perforate tectum and a densely columellate infra tectal layer; no carpels or remains of carpels could be observed on the floral axis. They also found that *Teixeiraea lusitanica* shows most affinities to members of Ranunculales.

**Age Justification:** (Dinis 2001; Dinis et al., 2002) suggested a Late Aptian age for the base of the Figueira da Foz Formation based on sedimentological and lithofacies correlations. ,correlation of a marine sequence in the Algarve Basin (dated on the basis of dinoflagellates and carbon-isotope data) with the sedimentary sequence in the Lusitanian Basin (western Portugal) has suggested that the base of the Figueira da Foz Formation could be slightly younger than previously thought, as to Early Albian. To be on the safe side, we used the age 121.4 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves::microscope: **${\text{\color{green} Fossil \ No.17}}$**

**Brief Desription:** The oldest fossil found in Proteales.

**Age Bounds:** 113.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Platanocarpus brookensis*, pistillate inflorescences, flowers and pollen grains, holotype PP42988, PP43044 and PP43038 et al., Subzone II-B zone, the "bank near Brooke" locality in the Patapsco Formation (Potomac Group) of northern Virginia, Cretaceous of the United States.

**Phylogenetic Justification:** (Crane et al., 1993) described the fossil *Platanocarpus brookensis* with features: Pistillate inflorescences and infructescences consist of flowers in globose aggregations that are borne directly on the inflorescence axis; Individual flowers are sessile and each consists of five free carpels, surrounded by a prominent perianth. They proposed the affinity to Platanaceae of this fossil.

**Age Justification:** The age of "bank near Brooke" of Subzone II-B zone was dated as early or middle Albian (Doyle and Hickey, 1976). Thus, we used the age 113.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.18}}$**

**Brief Desription:** The oldest fossil found in Trochodendrales.

**Age Bounds:** 72.3 - 66.0 mya.

**Taxon & Specimen & Rock:** *Tetracentronites panochetris*, Stanford University Paleontology Type Collection 6855, Panoche Formation (Great Valley Group), Del Puerto Canyon, Stanislaus County, California, Cretaceous of the United States.

**Phylogenetic Justification:** (Page 1968) first described the fossil *Tetracentronites panochetris* and (Andrews, 1970) assigned it to Trochodendrales.

**Age Justification:** According to (Page 1968), the age of Panoche Formation (Great Valley Group) was at Maastrichtian. Thus, we used the age 72.3 - 66.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.19}}$**

**Brief Desription:** The oldest fossil found in Buxales.

**Age Bounds:** 113.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Hexaporotricolpites lamellaferus*, Borehole 1-QS-1-MA, Sample 14, Preguicas Formation, Cretaceous of Brazil.

**Phylogenetic Justification:** (Herngreen, 1973) described the fossil *Hexaporotricolpites lamellaferus* and (Kotova, 1978) suggested of assigning *Hexaporotricolpites* to Didymelaceae.

**Age Justification:** The age of Preguicas Formation was dated as Lower Albian (Herngreen, 1973). Thus, we used the age 113.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.20}}$**

**Brief Desription:** The oldest fossil found in Gunnerales.

**Age Bounds:** 139.8 - 121.4 mya.

**Taxon & Specimen & Rock:** *Tricolpites sp.*, pollen, CA-5-1982, CU-40-1989, Springhill Formation, Doceava Región, Cretaceous of Chile.

**Phylogenetic Justification:** (Quattrocchio et al., 2006) reported the pollen of *Tricolpites sp.* and followed the classification of (Jarzen, 1982) to assign it to Gunneraceae.

**Age Justification:** Above the Springhill Formation is the Pampa Rincón Formation (*Inoceramus* Inferior or Shales with Chert) of Barremian - Early Aptian age (Natland et al., 1974), the age of Springhill Formation was estimated as Valanginian - Barremian (Quattrocchio et al., 2006). Thus, we used the age 139.8 - 121.4 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.21}}$**

**Brief Desription:** The oldest fossil found in Fagales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Myricipites sp.*, spores and pollen grain, Baoyuan track site, Wotoushan Formation (Jiaguan Formation), the Chishui area, Guizhou Province, Cretaceous of China

**Phylogenetic Justification:** (Xing et al., 2011) recovered the fossil as *Myricipites sp.* based on the morphology of spores and pollen grain. The classification of *Myricipites sp.* to Myricaceae follows the definition of (R. N. Lakhanpal et al., 1976).

**Age Justification:** *Myricipites sp.* was also found in Furao Formation of Heilongjiang Province at the Upper Cretaceous (Liu, 1983). The oldest of Wotoushan Formation can be at Lower Cretaceous (Xing et al., 2011). Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.22}}$**

**Brief Desription:** The oldest fossil found in Cucurbitales.

**Age Bounds:** 56.0 - 47.8 mya.

**Taxon & Specimen & Rock:** *Cucurbitospermum obliquum*, Lower Bagshot - Lake near Poole, Bagshot Formation, Eocene of the United Kingdom.

**Phylogenetic Justification:** (Chandler, 1962) assigned the fossil to genus *Cucurbitospermum* and described the fossil *Cucurbitospermum obliquum* and (Andrews, 1970) put the genus *Cucurbitospermum* to Cucurbitaceae..

**Age Justification:** (Chandler, 1962) adopted the age of Bagshot Formation to be Ypresian. Thus, we used the age 56.0 - 47.8 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.23}}$**

**Brief Desription:** The oldest fossil found in Rosales.

**Age Bounds:** 110.1 - 109.3 mya.

**Taxon & Specimen & Rock:** *Eophylica priscastellata* and *Phylica piloburmensis*, Burmese amber, Hkamti amber (QUST collection), Holotype No. QUST-AM32413 and No. QUST-AM32127, Sagaing, Cretaceous of Myanmar.

**Phylogenetic Justification:** (Shi et al., 2022) diagnosed the fossil species *Eophylica priscastellata* as identical to *Phylica* except with 8 sepals (2 × 4-merous) (versus 5 in Phylica), lacking petals (present in most *Phylica*, although secondarily reversed independently in several crown species), and indumentum composed of stellate rhamnaceous hairs (simple in *Phylica*). Ovary inferior, fused to receptacle. Style columnar, simple. Fruit a typical capsule, obovoid, about 5.0 mm long, crowned with persistent base of calyx with a convex calyx area. While for the fossil species *Phylica piloburmensis*, Leaves slightly wider (1.5–2.0 mm wide, 4.5–8.0 mm long) and both ad- and abaxial sides covered with simple linear hairs. Flowers not single but forming a capitulum. Petals present. Fruit covered with dense indumentum. They suggested of assigning these fossils to Rhamnaceae.

**Age Justification:** The fossil speceis *Eophylica priscastellata* was found in Tanaing mines and Hkamti mines, estimated as earliest Cenomanian (98.79 ± 0.62 mya) and early Albian (109.7 ± 0.4 mya), respectively. We used 110.1 - 109.3 mya as the age of the fossil.

:leaves: **${\text{\color{green} Fossil \ No.24}}$**

**Brief Desription:** The oldest fossil found in Fabales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Fontainea grandifolia*, Upper Belcourt Ridge, Commotion Formation, Cretaceous of Canada.

**Phylogenetic Justification:** (Mellon et al., 1963) reported and diagnosed the fossil as *Fontainea grandifolia*. (Andrews, 1970) proposed its assignment to Leguminosae.

**Age Justification:** The age of Commotion Formation was estimated as Lower Cretaceous. Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.25}}$**

**Brief Desription:** The oldest fossil found in Celastrales.

**Age Bounds:** 83.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Celastrinites wardii*, Extension 3771, Extension Formation (Nanaimo Group), Vancouver Island, British Columbia, Cretaceous of Canada.

**Phylogenetic Justification:** (Bell, 1957) reported the fossil species *Celastrinites wardii* on the flora of the Nanaimo Group. (Knowlton, 1919) proposed the phylogenetic assignment of *Celastrinites* to Celastraceae.

**Age Justification:** The age of Extension Formation was estimated to be Early Campanian (Hamblin, 2012). Thus, we used the age 83.8 - 71.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.26}}$**

**Brief Desription:** The oldest fossil found in Oxalidales.

**Age Bounds:** 83.8 - 66.0 mya

**Taxon & Specimen & Rock:** aff. *Elaeocarpus sp.*, leaves, ELA/RHA protophyll morphyotype, Zamek Hill assemblage, Zamek Formation, Zamek Hill, Admiralty Bay, Cretaceous of Antarctica.

**Phylogenetic Justification:** (Dutra and Batten, 2000) reported the leaf fossil of *Elaeocarpus sp.* after the morphological group of (Crabtree, 1987) and suggested its phylogenetic assignment to Elaeocarpaceae.

**Age Justification:** The age of Zamek Formation was suggested to be Late Campanian - Maastrichtian. Thus, we used the age 83.8 - 66.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.27}}$**

**Brief Desription:** The oldest fossil found in Malpighiales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Salix lesquereuxii* and *Salix flexuosa*, Chimney Bluff, Eutaw Formation, Chattahoochee County, Georgia, Cretaceous of the United States.

**Phylogenetic Justification:** (Berry, 1914) reported the two *Salix* fossils and (Knowlton, 1926) proposed its phylogenetic assignment to Salicaceae.

**Age Justification:** The age of Eutaw Formation was suggested to be Lower Cretaceous. Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.28}}$**

**Brief Desription:** The oldest fossil found in Zygophyllales.

**Age Bounds:** 72.3 - 66.0 mya.

**Taxon & Specimen & Rock:** *Guaiacum takliensis*, mesofossils, Takli Formation, Takli, Nagpur, Manharashtra, Cretaceous of India.

**Phylogenetic Justification:** (Hislop, 1861) reported the fossil *Guaiacum takliensis* and (Srivastava, 1991) classified it as Zygophyllaceae.

**Age Justification:** The age of Takli Formation was suggested to be Upper Maastrichtian. Thus, we used the age 72.3 - 66.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.29}}$**

**Brief Desription:** The oldest fossil found in Malvales.

**Age Bounds:** 113.0-100.5.

**Taxon & Specimen & Rock:** *Sterculia towneri*, macrofossils, 773 Hill Gould & Shattuck, Cheyenne Sandstone Formation, Kiowa County, Kansas, Cretaceous of the United States.

**Phylogenetic Justification:** (Berry, 1922) reported the fossil *Sterculia towneri* and (Prasad, 2008) classified it to Sterculiaceae.

**Age Justification:** The age of Cheyenne Sandstone Formation was estimated to be Albian. Thus, we used the age 113.0-100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.30}}$**

**Brief Desription:** The oldest fossil found in Brassicales.

**Age Bounds:** 66.0 - 61.6 mya (changed into 90.1 - 85.8 mya, according to (Santiago et al., 2020)).

**Taxon & Specimen & Rock:** *Akania sp.* ,leaf species MPEF-Pb-2020, Palacio de los Loros 2, Salamanca Formation, Paleocene of Argentina.

**Phylogenetic Justification:** (Iglesias et al., 2007) reported and identified the leaf fossil of *Akania sp.* by its morphology. (Wilf et al., 2005) adopted its phylogenetic assignment to Akaniaceae.

**Age Justification:** The Salamanca Formation is generally assigned to the Danian stage, based on forami nif era and ostracoda from the northern and eastern parts of the basin (Méndez, 1966; Bertels, 1975). Specifically, the foraminifera species present, including *Globanomalina* (*Turborotalia*) *compressa* and *Globoconusa daubjergensis*, reliably indicate an upper Danian age (zone P1c) for the marine Salamanca (Olsson et al., 1999). The Palacio de los Loros megafloras locally overlie the marine Salamanca while underlie the Banco Negro Inferior, can thus be well constrained to an age near the Danian-Selandian boundary. We used the age 66.0 - 61.6 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.31}}$**

**Brief Desription:** The oldest fossil found in Huerteales.

**Age Bounds:** 66.0 - 56.0 mya.

**Taxon & Specimen & Rock:** *Tapiscia serrata*, macrofossils, Genesee Locality, Alberta, Paleocene of Canada.

**Phylogenetic Justification:** (Chandrasekharam, 1974) reported the fossil *Tapiscia serrata* of the megafossil flora from the Genesee Locality and (Collinson et al., 2012) classified it as Tapisciaceae.

**Age Justification:** (Chandrasekharam, 1974) adopted the age of the megafossil flora to be at Paleocene. Thus, we used the age 66.0 - 56.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.32}}$**

**Brief Desription:** The oldest fossil found in Sapindales.

**Age Bounds:** 113.0 - 100.5 mya.

**Taxon & Specimen & Rock:** numerous *Sapindopsis* leaf fossils, Wayan Formation in southeast Idaho, Patapsco Formation of Virginia, Blackleaf Formation of Montana, Cretaceous North America.

**Phylogenetic Justification:** The leaf morphotypes was used to determine the *Sapindopsis* leaf fossil (Crabtree, 1987) and (Knowlton, 1919) adopted its phylogenetic assignment to Sapindaceae.

**Age Justification:** A probable new species of *Sapindopsis* of Middle Albian age is illustrated from rocks equivalent to the Thermopolis Shale in southwestern Montana. A putative Sapindophyll (cf. *Sapindopsis* sp.) from the Upper Albian of Idaho is tentatively assigned to this morphotype. The first angiosperm megafossil from the region, *Sapindopsis angusta* (Heer) Seward, occurs in the lower Middle Albian (Potomac subzone IIB). Thus, we used the age 113.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.33}}$**

**Brief Desription:** The oldest fossil found in Crossosomatales.

**Age Bounds:** 83.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Staphylea usheri*, macrofossils, Protection 3826, Protection Formation (Nanaimo Group), Cretaceous of Canada.

**Phylogenetic Justification:** *Staphylea usheri* was reported and identified in (Bell, 1957) following the classification of (Knowlton, 1919) that the genus *Staphylea* belongs to Staphyleaceae. 

**Age Justification:** The Protection Formation was estimated to be of early to late Campanian age (Hamblin, 2012). Thus, we used the age 83.8 - 71.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.34}}$**

**Brief Desription:** The oldest fossil found in Myrtales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Myrtaceidites eugeniioides*, sporo-pollen, Cabo Shirreff, Isla Livingston (Cretácico Inferior), Cretaceous of Antarctica.

**Phylogenetic Justification:** (Palma-Heldt et al., 2004) identified and reported the fossil *Myrtaceidites eugeniioides* based on the morphology. Following the classification of (Ruiz and Quattrocchio, 1997), we adopt it as belonging to Myrtales.

**Age Justification:** The age of Cabo Shirreff, Isla Livingston was estimated as Lower Cretaceous. Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.35}}$**

**Brief Desription:** The oldest fossil found in Geraniales.

**Age Bounds:** 66.0 - 23.03 mya.

**Taxon & Specimen & Rock:** *Simarubinium mahurzari*, macrofossils, Deccan Intertrappean Formation, Mahurzari, Paleogene of India.

**Phylogenetic Justification:** (Lakhanpal et al., 1976) in their category of Indian fossil plants described the fossil *Simarubinium mahurzari* and we followed the classification of (Knowlton, 1919) assigning it to Simarubaceae.

**Age Justification:** The age of Deccan Intertrappean Formation was estimated as Paleogene. Thus, we used the age 66.0 - 23.03 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.36}}$**

**Brief Desription:** The oldest fossil found in Vitales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Cissites ingens*, macrofossils, Minnekahta Falls, Cretaceous Formation, Cretaceous of the United States.

**Phylogenetic Justification:** (Ward, 1899) identified and reported the fossil *Cissites ingens*. Following (Berry, 1937), we adopted its phylogenetic assignment as Vitaceae.

**Age Justification:** The age of Minnekahta Falls, Cretaceous Formation was estimated as Lower Cretaceous. Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.37}}$**

**Brief Desription:** The oldest fossil found in Saxifragales.

**Age Bounds:** 113.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Trochodendroides potomacensis*, macrofossils, Blairmore Formation, Alberta, Canada.

**Phylogenetic Justification:** (Bell, 1956) in the lower Cretaceous floras of of Blairmore Formation identified and reported the fossil *Trochodendroides potomacensis*. (Liu et al., 1996) classified the *Trochodendroides* as Cercidiphyllaceae.

**Age Justification:** The age of Upper Blairmore Group was estimated as Albian. Thus, we used the age 113.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.38}}$**

**Brief Desription:** The oldest fossil found in Dilleniales.

**Age Bounds:** 86.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Dillenites paucidentatus*, macrofossils, Comox Coalfield 3769, Comox Formation (Nanaimo Group), Cretaceous of Canada.

**Phylogenetic Justification:** (Bell, 1957) reported the fossil species *Dillenites paucidentatus* on the flora of the Nanaimo Group, Comox Formation.

**Age Justification:** The age of Comox Formation was estimated to be mid-Santonian to early Campanian (Hamblin, 2012). Thus, we used the age 86.8 - 71.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.39}}$**

**Brief Desription:** The oldest fossil found in Santalales.

**Age Bounds:** 113.0 - 93.9 mya.

**Taxon & Specimen & Rock:** *Syncolporites marginatus*, pollen grains, Azx-1, Az04/1, N50/3-4, Azx-1, Az04/1, T46/2, Sample Az-03 of Baraka Formation Zone V (Maastrichtian), Sample Az-04 of Bentiu Formation Zone IV (Alb.-Cenom.), Cretaceous of Sudan.

**Phylogenetic Justification:** (Eisawi et al., 2012) identified the fossil *Syncolporites marginatus* based on the observation of pollen grains. Following (Hoorn, 1993), we adopted it as a member of Loranthaceae.

**Age Justification:** The fossil *Syncolporites marginatus* occurred in different Zones. The older one is Sample Az-04 of Zone IV, whose age was estimated as Albian to Cenomanian (Eisawi et al., 2012). Thus, we used the age 113.0 - 93.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.40}}$**

**Brief Desription:** The oldest fossil found in Caryophyllales.

**Age Bounds:** 125.77 - 113.0 mya.

**Taxon & Specimen & Rock:** *Droseridites senonicus*, pollen grains, Khx-1, Kh15/2, J52/3, Sample Kh- 15 of Abu Gabra Formation Zone II (Barremian-Aptian), Cretaceous of Sudan.

**Phylogenetic Justification:** (Eisawi et al., 2012) dianogsed and identified the fossil *Droseridites senonicus* based on the observation of pollen grains. Following (Deaf et al., 2014) we assigned it to Droseraceae.

**Age Justification:** The age of Abu Gabra Formation Zone II was Barremian-Aptian. Thus, we used the age 125.77 - 113.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.41}}$**

**Brief Desription:** The oldest fossil found in Cornales.

**Age Bounds:** 100.5 - 66.0 mya (changed into 90.1 - 85.8 mya, according to (Santiago et al., 2020)).

**Taxon & Specimen & Rock:** *Cornophyllum wardii*, mesofossils, P3651, Lance Formation, Niobrara County, Wyoming, Cretaceous of the United States.

**Phylogenetic Justification:** (Dorf, 1942) in the Cretaceous floras of the Rocky Mountain region dianogsed and identified the fossil *Cornophyllum wardii*. Following (Knowlton, 1919) we adopted its phylogenetic assignment as Cornaceae.

**Age Justification:** The age of Lance Formation was estimated as Upper Cretaceous (Dorf, 1942). Thus, we used the age 100.5 - 66.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.42}}$**

**Brief Desription:** The oldest fossil found in Icacinales.

**Age Bounds:** 59.2 - 56.0 mya.

**Taxon & Specimen & Rock:** *Natsiatum eocenicum*, mesofossils, Reading Beds - Broxbourne, Woolwich & Reading Beds Formation, Paleocene of the United Kingdom.

**Phylogenetic Justification:** (Chandler, 1961) identified and reported the fossil *Natsiatum eocenicum* on the Lower Tertiary Floras of Woolwich & Reading Beds Formation. We adopted the classification of (Collinson et al., 2012) to assign it to Icacinaceae.

**Age Justification:** The age of Woolwich & Reading Beds Formation was estimated as Thanetian. Thus, we used the age 59.2 - 56.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.43}}$**

**Brief Desription:** The oldest fossil found in Garryales.

**Age Bounds:** 66.0 - 63.3 mya.

**Taxon & Specimen & Rock:** *Eucommia serrata*, L.J. Hickey locality Bugger, Fort Union Formation, Bighorn Basin, Wyoming, Paleocene of the United States.

**Phylogenetic Justification:** (Wing et al., 1995) reported from the Bighorn Basin dataset the fossil *Eucommia serrata*. The phylogenetic assignment of it follows (Ozaki, 1974) to be Eucommiaceae.

**Age Justification:** The fossil *Eucommia serrata* was found on sedimentary rock dated as old as Puercan. Thus, we used the age 66.0 - 63.3 mya as the age of the fossil, according to the [Paleobiology Database](https://paleobiodb.org/#/).

:leaves: **${\text{\color{green} Fossil \ No.44}}$**

**Brief Desription:** The oldest fossil found in Boraginales.

**Age Bounds:** 66.0 - 61.6 mya.

**Taxon & Specimen & Rock:** *Cordioxylon prototrichotoma*, macrofossils, Puerto Visser, Visser Member (Peñas Coloradas Formation), Chubut, Paleocene of Argentina.

**Phylogenetic Justification:** (Brea and Zucol, 2006) reported the fossil *Cordioxylon prototrichotoma* from the Peñas Coloradas Formation and proposed it as Boraginaceae.

**Age Justification:** The age of Visser Member (Peñas Coloradas Formation) was estimated as Danian. Thus, we used the age 66.0 - 61.6 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.45}}$**

**Brief Desription:** The oldest fossil found in Gentianales.

**Age Bounds:** 66.0 - 61.6 mya.

**Taxon & Specimen & Rock:** *cf. Cricotriporites*, pollen, Danian samples 1, 3, 4, 6, 8, 11, San Ramon section, Lefipán Formation, Paleocene of Argentina.

**Phylogenetic Justification:** (Barreda et al.,2012) found and identified the fossil *cf. Cricotriporites*. Following the adoption of (Jaramillo and Dilcher., 2001) we set the fossil as Apocynaceae.

**Age Justification:** The fossil was solely found at Danian samples. Thus, we used the age 66.0 - 61.6 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.46}}$**

**Brief Desription:** The oldest fossil found in Lamiales.

**Age Bounds:** 145.0 - 66.0 mya.

**Taxon & Specimen & Rock:** *Bignonites chalianus*, macrofossils, Cerro Cachetamán, Chubut, Cretaceous of Argentina.

**Phylogenetic Justification:** (Menéndez, 1959) from the flora of the Castillo series found and classified the fossil *Bignonites chalianus* as Bignoniaceae.

**Age Justification:** The age of flora was estimated as Cretaceous (Menéndez, 1959). Thus, we used the age 145.0 - 66.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.47}}$**

**Brief Desription:** The oldest fossil found in Solanales.

**Age Bounds:** 56.0 - 47.8 mya.

**Taxon & Specimen & Rock:** *Perfotricolpites digitatus*, spore pollen, Catatumbo Basin II, II pollen zone, Mirador Formation, Norte de Santander, Eocene of Colombia.

**Phylogenetic Justification:** (González-Guzmán, 1967) reported the fossil *Perfotricolpites digitatus* on his work on the upper Los Cuervos and Mirador formations and decided the phylogenetic assignment at Convolvulaceae.

**Age Justification:** The age of the II pollen zone of Mirador Formation was estimated to be Lower Eocene. Thus, we used the age 56.0 - 47.8 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.48}}$**

**Brief Desription:** The oldest fossil found in Aquifoliales.

**Age Bounds:** 100.5 - 93.9 mya.

**Taxon & Specimen & Rock:** *Ilex serrata*, macrofossils, KJ9403 (DMNH 947), Dakota Formation, Grand County, Utah, Cretaceous of the United States.

**Phylogenetic Justification:** (Johnson, 2003) summarized the fossil records of Kirk Johnson fieldwork and identified the fossil *Ilex serrata*. Following the classification of (Liu et al., 1996) we assigned it to Aquifoliaceae.

**Age Justification:** The age of Dakota Formation was estimated as Cenomanian. Thus, we used the age 100.5 - 93.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.49}}$**

**Brief Desription:** The oldest fossil found in Escalloniales.

**Age Bounds:** 33.9 - 27.82 mya.

**Taxon & Specimen & Rock:** *Quintinia psilatispora*, pollen, Cethana Dam, Proteacidites tuberculatus pollen zone, Tasmania, Oligocene of Australia.

**Phylogenetic Justification:** (Hill, 1984) reported and identified the pollen fossil of *Quintinia psilatispora*. Following the opinion of (Jordan, 1997), we set it as Escalloniaceae.

**Age Bounds:** The age of Proteacidites tuberculatus pollen zone was estimated as Lower Oligocene. Thus, we used the age 33.9 - 27.82 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.50}}$**

**Brief Desription:** The oldest fossil found in Asterales.

**Age Bounds:** 86.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Calycithes sp.*, macrofossils, Comox Coalfield 3768, Comox Formation (Nanaimo Group), Cretaceous of Canada.

**Phylogenetic Justification:** (Bell, 1957) reported the fossil species *Calycithes sp.* on the flora of the Nanaimo Group. (MacGinitie, 1941) proposed the phylogenetic assignment of *Celastrinites* to Celastraceae.

**Age Justification:** The age of Comox Formation was estimated to be mid-Santonian to early Campanian (Hamblin, 2012). Thus, we used the age 86.8 - 71.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.51}}$**

**Brief Desription:** The oldest fossil found in Dipsacales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Viburnites Evansanus*, macrofossils, Hot Springs #2, Cretaceous Formation, South Dakota, Cretaceous of the United States.

**Phylogenetic Justification:** (Ward, 1899) found and identified the fossil *Viburnites Evansanus* at the Cretaceous Formation of the Black Hills. Following the classification of (Knowlton, 1919) we put it at Caprifoliaceae.

**Age Justification:** The age of Hot Springs #2, Cretaceous Formation was estimated as Lower Cretaceous. Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.52}}$**

**Brief Desription:** The oldest fossil found in Paracryphiales.

**Age Bounds:** 56.0 - 33.9 mya.

**Taxon & Specimen & Rock:** *Sphenostemon spp.*, Alcoa Anglesea locality, Site II , Lens A, Victoria, Eocene of Australia.

**Phylogenetic Justification:** (Christophel et al., 1987) from the Eocene flora of the Anglesea Locality discovered and identified the fossil *Sphenostemon spp.*. Following (Kershaw, 1976) we set it as Paracryphiaceae.

**Age Justification:** The age of the Eocene flora was estimated as Upper Eocene (Christophel et al., 1987). To be on the safe side, we used the age 56.0 - 33.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.53}}$**

**Brief Desription:** The oldest fossil found in Apiales.

**Age Bounds:** 145.0 - 100.5 mya.

**Taxon & Specimen & Rock:** *Aralia wellingtoniana*, macrofossils, Upper Belcourt Ridge, Commotion Formation, British Columbia, Cretaceous of Canada.

**Phylogenetic Justification:** (Mellon et al., 1963) reported and identified the fossil as *Aralia wellingtoniana*. Adopting the opinion of (Zhu et al, 2015), we assigned the fossil to Araliaceae.

**Age Justification:** The age of Commotion Formation was estimated as Lower Cretaceous. Thus, we used the age 145.0 - 100.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.54}}$**

**Brief Desription:** The oldest fossil found in Alismatales.

**Age Bounds:** 27.82 - 23.03 mya.

**Taxon & Specimen & Rock:** *Caldesia brandoniana*, fossil fruit, Forestdale, ca. 7 km east of Brandon, Vermont, Brandon Lignite Formation, Cenozoic of USA.

**Phylogenetic Justification:** (Kristina and Bruce, 1997) identified and reported the fossil fruit of *Caldesia brandoniana* by the morphological comparison with extant Alismataceae. We followed their phylogenetic assignment of this fossil to Alismataceae.

**Age Justification:** The genus has an extensive Oligocene through Pleistocene fossil record in Eurasia (Kristina and Bruce, 1997). Thus, we used the age 27.82 - 23.03 as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.55}}$**

**Brief Desription:** The oldest fossil found in Ericales.

**Age Bounds:** 83.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Actinocalyx bohrii*, fossil flower, Höganäs AB kaolin quarry at the Asen locality in the Kristianstad Basin, Scania, Cretaceous of Sweden.

**Phylogenetic Justification:** (Friis, 1985) identified and reported the fossil flower as actinomorphic, hypogynous, and pentamerous whose calyx is persistent, and upturned in the flowering stage. They resembled the extant Diapensiaceae the most. We adopted its phylogenetic assignment as Ericales.

**Age Justification:** The age of the sedimentary rock was estimated as Santonian to Campanian. Thus, we used the age 83.8 - 71.9 as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

## Monilophyta

:leaves: **${\text{\color{brown} Fossil \ No.01}}$**

**Brief Desription:** The oldest fossil found in Equisetales.

**Age Bounds:** 384.3 - 358.5 mya.

**Taxon & Specimen & Rock:** *Pseudobornia ursina*, coalified plant megafossils, north-eastern Alaska, Location 2, Collection Be 661 and Rr 635, Devonian of the United States.

**Phylogenetic Justification:** Collection Rr 635 revealed abundant detached foliar material of *Pseudobornia* and axial fragments probably representing the stems and branches of the same plant. A few of the fragments showing swollen nodes, some of which exhibited faint depressions probably marking branch scars, agreed well with the feature of *Pseudobornia* stems proposed by Nathorst.

**Age Justification:** Collection Rr 635 was unearthed (Mamay 1962) at Black shale immediately below Kanayut Conglomerate and above thrust fault. Given the known Late Devonian age of Kanayut Conglomerate, we used the age 384.3 - 358.5 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.02}}$**

**Brief Desription:** The oldest fossil found in Psilotales.

**Age Bounds:** 33.9 - 27.82 mya.

**Taxon & Specimen & Rock:** *Tmesipteris tasmanica*, macrofossils, Cethana Dam, Proteacidites tuberculatus pollen zone, Oligocene of Australia.

**Phylogenetic Justification:** The fossil *Tmesipteris tasmanica* was found at the early Eocene-Oligocene deposit at Cethana (Hill 1984). Following the classification of (Knowlton 1919) we put it at Psilotaceae.

**Age Justification:** The palynoflora has been reassigned to early Oligocene by (Macphail et al., 1994). Thus, we adopted the age 33.9 - 27.82 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.03}}$**

**Brief Desription:** The oldest fossil found in Ophioglossales.

**Age Bounds:** 251.926 - 251.2 mya.

**Taxon & Specimen & Rock:** *Lycopodiacidites spp.*, sporopollenin, Finnmark core 7129/10-U-01 layer 56.43m, Triassic of Norway.

**Phylogenetic Justification:** The fossil *Lycopodiacidites spp.* was found at the sandstone of the lowermost triassic succession, Finnmark Platform. Following the classification of (Dettmann 1986), we assign it as Ophioglossaceae.

**Age Justification:** The age of *Lundbladispora obsoleta*-*Tympanicysta stoschiana* Assemblage Zone was estimated as Griesbachian, based on palynological correlation with similar assemblages recorded elsewhere in the present Arctic region (Mangerud 1994). Thus, we adopted the age 251.926 - 251.2 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.04}}$**

**Brief Desription:** The oldest fossil found in Marattiales.

**Age Bounds:** 394.5 - 381.1 mya.

**Taxon & Specimen & Rock:** *Caulopteris antiqua* and *Caulopteris peregrina*, macrofossils, Corniferous Limestone Ohio, Corniferous Limestone Formation, Devonian of the United States.

**Phylogenetic Justification:** The two fossils were reported by (Dawson 1871). Following the classification of (Pfefferkorn 1976), we assign them as Marattiidae.

**Age Justification:** The age of Corniferous Limestone Formation was estimated as Middle Devonian. Thus, we adopted the age 394.5 - 381.1 mya as the age of the fossils, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.05}}$**

**Brief Desription:** The oldest fossil found in Osmundales.

**Age Bounds:** 359.3 - 322.8 mya.

**Taxon & Specimen & Rock:** *Todeopsis primaeva*, macrofossil, Flora at Esnost Locality, Carboniferous of France.

**Phylogenetic Justification:** (Scott et al, 1984) reported and identified the fossil *Todeopsis primaeva* according to the definition of (Renault 1896).

**Age Justification:** As shown in the Table 1 of (Scott et al, 1984), the fossil *Todeopsis primaeva* was only unearthed at Esnost Locality, the stratigraphical age of which was estimated as Dinantian based on the compression flora associated with the anthracites and the cherts around the edge of the Autun basin, the radiometric date of which was 323-333 mya. Thus, we adopted the Mississippian age 359.3 - 322.8 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.06}}$**

**Brief Desription:** The oldest fossil found in Gleicheniales.

**Age Bounds:** 323.6 - 298.75 mya.

**Taxon & Specimen & Rock:** *Oligocarpia leptophylla*, macrofossil, Pejão Coalfield flora and the adjoining Paraduça No 1 Mine, Dura Basin, Carboniferous of North Portugal.

**Phylogenetic Justification:** (Sousa and Wagner 1983) reported the fossil *Oligocarpia leptophylla* and we assigned it as Gleicheniaceae following the classification of (Andrews 1970).

**Age Justification:** The age of the sedimentary rock was estimated Pennsylvanian. Thus, we adopted the age 323.6 - 298.75 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.07}}$**

**Brief Desription:** The oldest fossil found in Schizaeales.

**Age Bounds:** 323.6 - 298.75 mya.

**Taxon & Specimen & Rock:** *Senftenbergia pennaeformis*, coalified macrofossil, Stewart Mazon Creek and Linopteris obliqua zone, Chieftain No.20 Flora of Vigo County, Busseron Sandstone Member, Shelburn Formation, Indiana, Carboniferous of the United States.

**Phylogenetic Justification:** As shown in the Figure 2 (Boneham 1974), the pinnules have a triangular shape but are longer than those reported for *Dactylotheca plumosa* (Artis) Zeiller whose outline *Senftenbergia pennaeformis* Brongniart otherwise resembles. We accepted the classification of *Senftenbergia pennaeformis* Brongniart.

**Age Justification:** The age of Chieftain No.20 Flora of Vigo County was estimated as Upper Allegheny or lower-most Conemaugh. Thus, we adopted the Pennsylvanian age 323.6 - 298.75 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.08}}$**

**Brief Desription:** The oldest fossil found in Salviniales.

**Age Bounds:** 132.6 - 125.77 mya.

**Taxon & Specimen & Rock:** *Crybelosporites striatus*, spore-pollen, Alam El-Beuib Member, Burg El-Arab Formation, West Tiba-1, Assemblage Zone PII, Sample 9, Cretaceous of Egypt.

**Phylogenetic Justification:** (Mahmoud and Moawad 2000) reported and identified the spore-pollen *Crybelosporites striatus* based on palynology.

**Age Justification:** *Crybelosporites striatus* was unearthed at Ephedripites-Aequitriradites verrucosus Assemblage Zone PII, whose age was estimated as Hauterivian based on the recovered palynomorphs. Thus, we adopted the age 132.6 - 125.77 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{brown} Fossil \ No.09}}$**

**Brief Desription:** The oldest fossil found in Cyatheales.

**Age Bounds:** 132.6 - 125.77 mya.

## Upper Limits

The minimum age constraint for a given clade can be obtained simply from the lower limit of the stratigraphic age in which the oldest fossil was reported, as we justified above. However, the corresponding maximum age constraint for a given clade, is predominantly based on the knowledge and viewpoint of the researcher. The overall stratigraphic distribution of the fossils of crown and stem groups of the given clade, and the age estimates from the molecular dating studies pertaining to the given clade are the major references for determining a safe maximum age constraint. On top of this, with the unearthing of even older fossils nowadays, the upper limit, i.e. the maximum age constraint of any given clade, will be pushed older concomitantly. Here, we provided, in the best of our knowledge, the safe maximum age constraint for some clades and the associated Justification.

## References
A. A. M. Eisawi, A. B. Ibrahim, O. B. A. Rahim and E. Schrank. (2012). Palynozonation of the Cretaceous to Lower Paleogene Strata of the Muglad Basin, Sudan. Palynology, 36(2): 191-207.

A. Chandrasekharam. (1974). Megafossil flora from the Genesee Locality, Alberta, Canada. Palaeontographica Abteilung B, 147: 1-41.

A. C. Scott, J. Galtier, and G. Clayton. (1984). Distribution of anatomically-preserved floras in the Lower Carboniferous in Western Europe. Transactions of the Royal Society of Edinburgh, 75: 311-340.

A. E. González-Guzmán. (1967). A palynological study on the upper Los Cuervos and Mirador formations (Lower and middle Eocene; Tibu area, Colombia). 1-68.

A. Iglesias, P. Wilf, K. R. Johnson, A. B. Zamuner, N. R. Cúneo and S. D. Matheos. (2007). A Paleocene lowland macroflora from Patagonia reveals signifcantly greater richness than North American analogs. Geology 35(10): 947-950.

A.P. Hamblin (2012). Upper Cretaceous Nanaimo Group of Vancouver Island as a potential bedrock aquifer zone: summary of previous literature and concepts. GEOLOGICAL SURVEY OF CANADA OPEN FILE 7265.

A. P. Kershaw. (1976). A Late Pleistocene and Holocene pollen diagram from Lynch’s Crater, northeastern Queensland, Australia. New Phytologist, 77: 469-498.

Barreda VD, Cúneo NR, Wilf P, Currano ED, Scasso RA, et al. (2012) Cretaceous/Paleogene Floral Turnover in Patagonia: Drop in Diversity, Low Extinction, and a Classopollis Spike. PLOS ONE, 7(12): e52455.

Bell, W. A. (1949). Uppermost Cretaceous and Paleocene floras of western Alberta. Bulletin, Geological Survey of Canada, 13: 1–231.

Bertels, A., (1975). Bioestratigrafía del Paleógeno en la República Argentina: Revista Española de Micropaleontología, v. 7, p. 429–450.

Brenner, G.J. (1963). The spores and pollen of the Potomac Group of Maryland. Maryland Department of Geology, Mines and Water Resources, 27: 215.

Brenner, G. J. and Bickoff, I. S. (1992). Palynology and Age of the Lower Cretaceous Basal Kurnub Group from the Coastal Plain to the Northern Negev of Israel. Palynology, 16: 137–185.

C. A. Jaramillo and D. L. Dilcher. (2001). Middle Paleogene palynology of Central Colombia, South America: A study of pollen and spores from tropical latitudes. Palaeontographica Abteilung B, 258(4-6): 87-213.

C. A. Menéndez. (1959). Flora cretacica de la serie del Castillo al S del Cerro Cachetaman, Chubut. Revista de la Asociación Geológica Argentina XIV(3-4): 219-238.

C. Hoorn. (1993). Marine incursions and the influence of Adean tectonics on the Miocene depositional history of northwestern Amazonia: results of a palynostratigraphic study. Palaeogeography, Palaeoclimatology, Palaeoecology, 105: 267-309.

Crabtree, D. R. (1987). Angiosperms of the Northern Rocky Mountains: Albian to Campanian (Cretaceous) Megafossil Floras. Annals of the Missouri Botanical Garden, 74(4): 707–747.

David K. Ferguson, Daphne E. Lee, Jennifer M. Bannister, Reinhard Zetter, Gregory J. Jordan, Norbert Vavra, Dallas C. Mildenhall (2010). The taphonomy of a remarkable leaf bed assemblage from the Late Oligocene–Early Miocene Gore Lignite Measures, southern New Zealand. International Journal of Coal Geology, 83(2-3): 173-181.

D. C. Christophel, W. K. Harris, and A. K. Syber. (1987). The Eocene flora of the Anglesea Locality, Victoria. Alcheringa, 11(4): 303-323.

de Lima, M. R. (1982). Palinologia da Formação Codó na região de Codó, Maranhão. Boletim IG, 13: 116-128.

Dinis JL (2001). Definition of the Figueira da Foz Formation:Aptianto Cenomanian of the central sector of the western Iberian margin. Comun Inst Geol Min, 88:127–160.

Dinis JL, J Rey and P-C de Graciansky (2002). Le bassin lusitanien (Portugal) à l’Aptien supérieur-Albien: organisation séquentielle, proposition de corre´lations, évolution. CR Geosci, 334: 757–764.

D. M. Jarzen. (1982). Palynology of Dinosaur Provincial Park (Campanian) Alberta. Syllogeus, 38: 1-69.

Doyle, J.A. (1992). Revised palynological correlations of the lower Potomac Group (USA) and the Cocobeach sequence of Gabon (Barremian–Aptian). Cretaceous Research, 13: 337–349.

Doyle, J. A., and E. I. Robbins. (1977). Angiosperm pollen zonation of the continental Cretaceous of the Atlantic Coastal Plain and its application to deep wells in the Salisbury Embayment. Palynology, 1: 43–78.

Doyle, J.A., P. Biens, A. Doerenkamp and S. Jardiné. (1977). Angiosperm pollen from the pre-Albian Lower Cretaceous of Equatorial Africa. Bulletin Centres Rescherches Exploration-Production Elf-Aquitaine, 1:451-473.

Doyle, J.A., Jardiné, S., Doerenkamp, A. (1982). *Afropollis*, a new genus of early angiosperm pollen, with notes on the Cretaceous palynostratigraphy and palaeoenvironments of northern Gondwana. Bulletin. Centres de Recherches Exploration-Production Elf-Aquitaine, 6: 39–117.

Doyle, J.A. and L. J. HICKEY. (1976). Pollen and leaves from the mid-Cretaceous Potomac Group and their bearing on early angiosperm evolution. Pp. 139- 206 in *Origin and early evolution of angiosperms*, ed. C. B. Beck. New York: Columbia Univ. Press.

E. Dorf. (1942). Upper Cretaceous floras of the Rocky Mountain region; Flora of the Lance Formation at its type locality, Niobrara County, Wyoming. Contributions to Palaeontology.

E. M. Friis (1985). *Actinocalyx* gen. nov., sympetalous angiosperm flowers from the upper cretaceous of southern Sweden. Review of Palaeobotany and Palynology, 45(3-4): 171-183.

E. M. Friis, K. R. Pedersen, and P. R. Crane. (1995). *Appomattoxia ancistrophora* gen. et sp. nov., a new Early Cretaceous plant with similarities to Circaeaster and extant Magnoliidae. American Journal of Botany, 82(7): 933-943.

E. M. Friis, P. R. Crane, and K. R. Pedersen. (1988). Reproductive structures of Cretaceous Platanaceae. Biologiske Skrifter Det Kongelige Danske Videnskskabernes Selskab, 31: 1-55.

E. Schrank and M. S. Mahmoud. (2002). Barremian angiosperm pollen and associated palynomorphs from the Dakhla Oasis Area, Egypt. Palaeontology, 45(1): 33-56.

E. W. Berry. (1914). The Upper Cretaceous and Eocene floras of South Carolina and Georgia. US Geological Survey Professional Paper 84: 1-200.

E. W. Berry. (1922). The flora of the Cheyenne Sandstone of Kansas. United States Geological Survey Professional Paper 129(1): 199-231.

F. H. Knowlton. (1919). A catalogue of the Mesozoic and Cenozoic plants of North America. United States Geological Survey Bulletin, 696: 1-815.

F. H. Knowlton. (1926). Flora of the Latah formation of Spokane, Washington, and Coeur d'Alene, Idaho. US Geological Survey Professional Paper 140(A): 17-55.

G.B. Mellon, J.H. Hall, and C.R. Stelck. (1963). Lower Cretaceous Section, Belcourt Ridge, Northeastern British Columbia. Bulletin of Canadian Petroleum Geology 11: 64-72.

G. F. W. Herngreen. (1973). Palynology of the Albian-Cenomanian strata of Borehole 1-QS-1-MA, State of Maranhao, Brazil. Pollen et Spores, 15(3-4): 515-555.

G. J. Jordan. (1997). Evidence of Pleistocene plant extinction and diversity from Regatta Point, western Tasmania, Australia. Botanical Journal of the Linnean Society, 123: 45-71.

G. Mangerud. (1994). Palynostratigraphy of the Permian and lowermost Triassic succession, Finnmark Platform, Barents Sea. Review of Palaeobotany and Palynology, 82: 317-349.

Grader, P. and Reiss Z. (1958). On the Lower Cretaceous of Heletz Area. Geological Survey of Israel, 16: 14.

Haggard, K. K., and Tiffney, B. H. (1997). The Flora of the Early Miocene Brandon Lignite, Vermont, USA. VIII. Caldesia (Alismataceae). American Journal of Botany, 84(2): 239–252.

Harland, W. B., R. L. Armstrong, A. V. Cox, L. A. Craig, A. G. Smith, and D. G. Smith. (1989). A geologic time scale. Cambridge University Press, Cambridge, UK.

H. D. MacGinitie. (1941). A Middle Eocene Flora from the Central Sierra Nevada. Carnegie Institution of Washington Publication, 534: 1-178.

H. D. MacGinitie. (1953). Fossil Plants of the Florissant Beds of Colorado. Carnegie Inst. of Washington, Contributions to Paleontology Publ, 599: 1-198.

Huasheng Huang, Robert J. Morley, Alexis Licht, Guillaume Dupont-Nivet, Daniel Pérez-Pinedo, Jan Westerweel, Zaw Win, Day Wa Aung, Eko Budi Lelono, Galina N. Aleksandrova, Ramesh K. Saxena, Carina Hoorn (2023). A proto-monsoonal climate in the late Eocene of Southeast Asia: Evidence from a sedimentary record in central Myanmar. Geoscience Frontiers, 14(1): 101457.

H. N. Andrews. (1970). Index of Generic Names of Fossil Plants, 1820-1965. Geological Survey Bulletin, 1-354.

H. Zhu, Y. J. Huang, and Z. K. Zhou. (2015). Systematic descriptions, in Fossil endocarps of Aralia (Araliaceae) from the upper Pliocene of Yunnan in southwest China, and their biogeographical implications. Review of Palaeobotany and Palynology, 223: 94-103.

H. W. Pfefferkorn. (1976). Pennsylvanian tree fern compressions Caulopteris, Megaphyton, and Artisophyton gen. nov. in Illinois. Illinois State Geological Survey Circular, 492: 1-31.

Isaac, M.J. and Lindqvist, J.K. (1990). Geology and lignite resources of the East Southland Group, New Zealand. New Zealand Geological Survey Bulletin, 101: 1–202.

I. Z. Kotova. (1978). Spores and pollen from Cretaceous deposits of the eastern North Atlantic Ocean, Deep Sea Drealing Project, Leg. 41, Sites 367 and 370. Deep Sea Drealing Project, 41: 841-881.

J. W. Dawson. (1871). On New Tree Ferns and Other Fossils from the Devonian. Quarterly Journal of the Geological Sciences, 27: 269-278.

K. Ozaki. (1974). Miocene floras of the Pacific side of central Japan (I) Inkyoyama flora. Science Reports of the Yokohama National University, Section II, 21: 1-21.

K. R. Johnson. (2003). Denver Museum of Nature & Science archival records of Kirk Johnson fieldwork in Cretaceous rocks of the Rocky Mountain region.

L. Duarte and R.Silva Santos (1993). Plant and fish megafossils of the Codó Formation, Parnaıba Basin, NE Brazil. Cretaceous Research, 14(6): 735-746.

L.-d. Xing, J. D. Harris, G. D. Gierlinski, W.-m. Wang, Z.-y. Wang and D.-q. Li. (2011). Middle Cretaceous non–avian theropod trackways from the southern margin of the Sichuan Basin, China. Acta Palaeontologica Sinica, 50(4): 470-480.

Leticia Karina Povilauskas (2013). Palinología de Angiospermas de la Formación Monte Chico (Cretácico Superior) de la Provincia de Santa Cruz, Argentina. Revista Brasileira de Paleontologia 16(1): 115-126.

L.F. Ward. (1899). The Cretaceous formation of the Black Hills as indicated by the fossil plants. Cretaceous Formation of the Black Hills.

Liu Mu-ling 1983, The late Upper Cretaceous to Palaeogene sporen pollen assemblages from the Furao area, Heilongjiang Province.Bulletin of the Shenyang Institute of Geology and Mineral Resources, Chinese Academy of Geological Sciences, 7: 99-132.

L. Povilauskas. (2013). Palinología de Angiospermas de la Formación Monte Chico (Cretácico Superior) de la Provincia de Santa Cruz, Argentina. Revista Brasileira de Paleontologia, 16(1):115-126.

M. Brea and A. F. Zucol. (2006). Leños fósiles de Boraginaceae de la Formación Peñas Coloradas (Paleoceno superior), Puerto Visser, Chubut, Argentina. Ameghiniana, 43(1): 139-146.

Méndez, I. (1966). Foraminíferos, edad y correlación estratigráfi ca del Salamanquense de Punta Peligro (45°30′S; 67°11′W), provincia del Chubut: Revista de la Asociación Geológica Argentina, v. 21, p. 127–157.

M. E. Dettmann. (1986). Early Cretaceous palynoflora of subsurface strata correlative with the Koonwarra Fossil Bed, Victoria. Mem. Ass. Auslralas. Palaeontols, 3: 79-110.

M. E. Collinson, S. R. Manchester, and V. Wilde. (2012). Fossil Fruits and Seeds of the Middle Eocene Messel biota, Germany. Abhandlungen der Senckenbergischen Gesellschaft Naturforschenden 570: 1-249.

M. E. Quattrocchio, M. A. Martínez, A. Carpinelli Pavisich and W. Volkheimer. (2006). Early Cretaceous palynostratigraphy, palynofacies and palaeoenvironments of well sections in northeastern Tierra del Fuego, Argentina. Cretaceous Research, 27: 584-602.

M. E. J. Chandler. (1961). The Lower Tertiary Floras of Southern England. I. Palaeocene Floras. London Clay Flora (Supplement), 1-354.

M. E. J. Chandler. (1962). The Lower Tertiary Floras of Southern England. II. Flora of the Pipe-Clay Series of Dorset (Lower Bagshot). British Museum (Natural History) London, 1-176.

Mildenhall, D.C. (1979). Palynology of the Waipipian and Hautawan Stages (Pliocene and Pleistocene), Wanganui, New Zealand (note). New Zealand Journal of Geology and Geophysics, 21:775-777.

Mildenhall, D.C. and Pocknall, D.T. (1989). Miocene–Pleistocene spores and pollen from Central Otago, South Island, New Zealand. New Zealand Geological Survey Paleontological Bulletin, 59: 1–128.

M. J. de Sousa and R. H. Wagner. (1983). New data on the fossil flora of the Pejão Coalfield and the adjoining Paraduça No 1 Mine (Dura Basin, North Portugal). Contributions to the Carboniferous Geology and Palaeontology of the Iberian Peninsula, 157-170.

Macphail, M., Alley, F., Truswell, E. and Sluiter, I. R. K.: Early Tertiary vegetation: Evidence from spores and pollen, in History of the Australian Vegetation: Cretaceous to Recent, edited by R. S. Hill, pp. 189–261, Cambridge University Press, Cambridge., 1994.

M. Prasad. (2008). Angiospermous fossil leaves from the Siwalik foreland basins and their palaeoclimatic implications. The Palaeobotanist, 57: 177-215.

M. S. Mahmoud and A.-R. M. Moawad. (2000). Jurassic-Cretaceous (Bathonian to Cenomanian) palynology and stratigraphy of the West Tiba-1 borehole, northern Western Desert, Egypt. Journal of African Earth Sciences, 30: 401-416.

Natland, M.L., Gonzalez, E., Cañon, A. and Ernst, M. (1974). A system of stages for correlation of Magallanes Basin sediments. Geological Society of America, Memoir, 139, 1-126.

Ogg, James,  Ogg, Gabi and Gradstein, Felix. (2016). A Concise Geologic TimeScale.

Olsson, R.K., Berggren, W.A., Hemleben, C., and Huber, B.T. (1999). Atlas of Paleocene planktonic foraminifera: Smithsonian Contributions to Paleobiology, v. 85, p. 1–252.

P. Wilf, K. R. Johnson, N. R. Cúneo, M. E. Smith, B. S. Singer and M. A. Gandolfo. (2005). Eocene Plant Diversity at Laguna del Hunco and Río Pichileufú, Patagonia, Argentina. The American Naturalist, 165(6): 634-650.

Patil, G. V., & Singh, R. B. (1978). Fossil Eichhornia from the Eocene Deccan Intertrappean beds, India. Palaeontographica Abteilung B-Palaophytologie.

Pocknall, D.T. and Mildenhall, D.C. (1984). Late Oligocene–early Miocene spores and pollen from Southland, New Zealand. New Zealand Geological Survey Paleontological Bulletin, 51: 1–66.

Pons, D., Berthou, P.Y., Filgueira, J.B.M., Sampaio, J.J.A. (1996). Palynologie des unités lithostratigraphique “Fundao”, “Crato” et “Ipubi” (Aptien supérieur à Albien inférieurmoyen, Bassin d'Araripe, NE du Brésil): enseignements paléoécologiques, stratigraphiques et climatologiques. In: Jardiné, S., Klasz, I., Debenet, J.-P. (Eds.), Géologie de l'Afrique et de l'Atlantique Sud. Elf Aquitaine Memoire, Pau, pp. 383–401.

Q. C. Huang and D. L. Dilcher. (1994). Evolutionary and Paleoecological Implications of Fossil Plants from the Lower Cretaceous Cheyenne Sandstone of the Western Interior. Geological Society of America Special Paper, 287:129-144.

R. F. Boneham. (1974). Chieftain No.20 Flora (Middle Pennsylvanian) of Vigo County Indiana. Proceedings of the Indiana Academy of Science, 84: 89-113.

Regali, M.S.P. (2001). Palinoestratigrafia dos sedimentos Cretácicos da Bacia do Araripe e das Bacias Interiores do Nordeste—Brasil. In: Barros, L.M., Nuvens, P.C., Filgueira, J.B.M. (Eds.), I e II Simpósios Sobre a Bacia do Araripe e Bacias Interiores do Nordeste. Universidade Regional do Cariri—URCA, Crato, pp. 101–108.

Rios-Netto, A.M., Regali, M.S.P. (2007). Estudo bioestratigráfico, paleoclimático e paleoambiental do intervalo Alagoas (Cretáceo Inferior) da Bacia do Araripe, Nordeste do Brasil (Poço 1-PS-11-CE). Paleontologia: Cenários de Vida. Interciência, Rio de Janeiro, pp. 481–490.

R. N. Lakhanpal, H. K. Maheshwari, and N. Awasthi. (1976). A Catalogue of Indian Fossil Plants. 1-318.

R. Srivastava. (1991). A Catalogue of Fossil Plants from India Part 4: Cenozoic (Tertiary) Megafossils. 1-45.

R. S. Hill. (1984). Tertiary Nothofagus macrofossils from Cethana, Tasmania. Alcheringa, 8(1): 81-86.

S. Archangelsky. (1973). Palinología del Paleoceno de Chubut. I. Descripciones Sistemáticas. Ameghiniana, 10(4): 339-399.

S. Archangelsky, A. Archangelsky, and G. Cladera. (2012). Palinología y paleoambientes en el perfil de Bajo Comisión (Cretácico), provincia de Santa Cruz, Argentina. Revista del Museo Argentino de Ciencias Naturales, 14(1):23-39.

Shi, C., Wang, S., Cai, Hh. et al. (2022). Fire-prone Rhamnaceae with South African affinities in Cretaceous Myanmar amber. Nat. Plants 8, 125–135.

S. H. Mamay. (1962). Occurrence of Pseudobornia Nathorst in Alaska. The Palaeobotanist, 11(1): 19-22.

Satish K. Srivastava, Dennis R. Braman (2010). The revised generic diagnosis, specific description and synonymy of the Late Cretaceous *Rosannia manika* from Alberta, Canada: Its phytogeography and affinity with family Lactoridaceae. Review of Palaeobotany and Palynology, 159(1–2): 2-13.

S. L. Wing, J. Alroy, and L. J. Hickey. (1995). Plant and mammal diversity in the Paleocene to Early Eocene of the Bighorn Basin. Palaeogeography, Palaeoclimatology, Palaeoecology, 115: 117-155.

Scott R.W. (2009). Uppermost Albian biostratigraphy and chronostratigraphy. Carnets de Géologie / Notebooks on Geology, Brest, Article 2009/03 (CG2009_A03)

S. Hislop. (1861). Remarks on the geology of Nágpur. Journal of the Bombay Branch of the Royal Asiatic Society, 6: 194-204.

Swisher, C.C., Wang, Y.Q., Wang, X.L., Xu, X. and Wang, Y. (1999). Cretaceous age for the feathered dinosaurs of Liaoning, China. Nature, 400: 58–61.

T. L. Dutra and D. J. Batten. (2000). Upper Cretaceous floras of King George Island, West Antarctica, and their palaeoenvironmental and phytogeographic implications. Cretaceous Research, (21): 181-209.

Ulrich Heimhofer, Peter-A. Hochuli (2010). Early Cretaceous angiosperm pollen from a low-latitude succession (Araripe Basin, NE Brazil). Review of Palaeobotany and Palynology, 161(3-4): 105-126.

V. D. Barreda, N. R. Cúneo, P. Wilf, E. D. Currano, R. A. Scasso and H. Brinkhuis. (2012). Cretaceous/Paleogene Floral Turnover in Patagonia: Drop in Diversity, Low Extinction, and a Classopollis Spike. PLoS ONE, 7(12): e52455.

V. M. Page. (1968). Angiosperm Wood from the Upper Creataceous of Central California: Part II. American Journal of Botany, 55(2): 168-172.

W. A. Bell. (1956). Lower Cretaceous Floras of Western Canada. Geological Survey of Canada Memoir 285(2528): 1-153.

W. A. Bell. (1957). Flora of the Upper Cretaceous Nanaimo Group of Vancouver Island, British Columbia. Geological Survey of Canada Memoir, 293: 1-84.

Y.-S. Liu, S.-X. Guo, and D. K. Ferguson. (1996). A catalogue of Cenozoic megafossil plants in China. Palaeontographica Abteilung B, 238: 141-179.

Zhengyao Cao, Shunqing Wu, Ping'an and Li Jieru Zhang (1998). Discovery of fossil monocotyledons from Yixian Formation, western Liaoning. Chinese Science Bulletin, 43(3): 230-233.
